==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebSortingOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSortingOptionsDescription } from "./WebSortingOptionsDescription";
/**
 * @hidden
 */
export let WebSortingOptionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSortingOptionsDescriptionMetadata extends Base {
        static b(a) {
            if (WebSortingOptionsDescriptionMetadata.a == null) {
                WebSortingOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSortingOptionsDescriptionMetadata.c(WebSortingOptionsDescriptionMetadata.a);
            }
            if (a.k(WebSortingOptionsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebSortingOptionsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:SortingOptions");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Mode", "ExportedType:string:SortingOptionsMode");
            a.item("Mode@stringUnion", "WebComponents;React");
            a.item("Mode@names", "Single;Multiple");
        }
        static d(a) {
            WebSortingOptionsDescriptionMetadata.b(a);
            a.ad("WebSortingOptions", () => new WebSortingOptionsDescription());
            a.ac("WebSortingOptions", WebSortingOptionsDescriptionMetadata.a);
        }
    }
    WebSortingOptionsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebSortingOptionsDescriptionMetadata, 'WebSortingOptionsDescriptionMetadata');
    WebSortingOptionsDescriptionMetadata.a = null;
    return WebSortingOptionsDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/WebSortingOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSortingOptionsDescription } from "./WebSortingOptionsDescription";
/**
 * @hidden
 */
export let WebSortingOptionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSortingOptionsDescriptionMetadata extends Base {
        static b(a) {
            if (WebSortingOptionsDescriptionMetadata.a == null) {
                WebSortingOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSortingOptionsDescriptionMetadata.c(WebSortingOptionsDescriptionMetadata.a);
            }
            if (a.k(WebSortingOptionsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebSortingOptionsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:SortingOptions");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Mode", "ExportedType:string:SortingOptionsMode");
            a.item("Mode@stringUnion", "WebComponents;React");
            a.item("Mode@names", "Single;Multiple");
        }
        static d(a) {
            WebSortingOptionsDescriptionMetadata.b(a);
            a.ae("WebSortingOptions", () => new WebSortingOptionsDescription());
            a.ad("WebSortingOptions", WebSortingOptionsDescriptionMetadata.a);
        }
    }
    WebSortingOptionsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebSortingOptionsDescriptionMetadata, 'WebSortingOptionsDescriptionMetadata');
    WebSortingOptionsDescriptionMetadata.a = null;
    return WebSortingOptionsDescriptionMetadata;
})();
